@@ -3,7 +3,7 @@
  * This file contains the Horde_Service_Weather class for communicating with
  * the weather underground service.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * @author   Michael J Rubinsky <mrubinsk@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -283,10 +283,10 @@ class Horde_Service_Weather_WeatherUnderground extends Horde_Service_Weather_Bas
             'state' => $station->state,
             'country' => $station->country_iso3166,
             'country_name' => $station->country_name,
-            'tz' => $station->tz_long,
-            'lat' => $station->lat,
-            'lon' => $station->lon,
-            'zip' => $station->zip,
+            'tz' => isset($station->tz_long) ? $station->tz_long : '',
+            'lat' => isset($station->lat) ? $station->lat : '',
+            'lon' => isset($station->lon) ? $station->lon : '',
+            'zip' => isset($station->zip) ? $station->zip : '',
             'code' => str_replace('/q/', '', $station->l)
         );
 
@@ -369,7 +369,7 @@ class Horde_Service_Weather_WeatherUnderground extends Horde_Service_Weather_Bas
         if ((!empty($this->_cache) && !$results = $this->_cache->get($cachekey, $lifetime)) ||
             empty($this->_cache)) {
             $url = new Horde_Url($url);
-            $response = $this->_http->get($url);
+            $response = $this->_http->get((string)$url);
             if (!$response->code == '200') {
                 throw new Horde_Service_Weather_Exception($response->code);
             }
